@@ -1,6 +1,6 @@
 package Bundle::DadaMail::IncludedInDistribution;
 
-$VERSION = '0.0.2';
+$VERSION = '0.0.3';
 
 1;
 
@@ -86,7 +86,7 @@ Data::Page - prereq to DataPageset
 
 Date::Format - prereq to something
 
-DataPageset
+Data::Pageset
 
 Digest::SHA::PurePerl - weird 'cause Digest::SHA is core
 
@@ -156,6 +156,8 @@ Text::Balanced
 
 PHP::Session
 
+Text::Abbrev
+
 Text::CSV 
 
 Text::FrontMatter::YAML
